@@ -14,9 +14,7 @@
 # under the License.
 import json
 import logging
-import os
 import time
-import yaml
 
 from heatclient.common import deployment_utils
 from heatclient import exc as heat_exc
@@ -166,6 +164,7 @@ class DeployStackAction(templates.ProcessTemplatesAction):
             LOG.exception(err_msg)
             return actions.Result(error=err_msg)
 
+        self.set_tls_parameters(parameters, env)
         try:
             plan_utils.update_in_env(swift, env, 'parameter_defaults',
                                      parameters)
@@ -197,21 +196,44 @@ class DeployStackAction(templates.ProcessTemplatesAction):
             except swiftexceptions.ClientException:
                 pass
             LOG.info("Perfoming Heat stack create")
-            try:
-                return heat.stacks.create(**stack_args)
-            except heat_exc.HTTPException as err:
-                err_msg = "Error during stack creation: %s" % (err,)
-                LOG.exception(err_msg)
-                return actions.Result(error=err_msg)
+            return heat.stacks.create(**stack_args)
 
         LOG.info("Performing Heat stack update")
         stack_args['existing'] = 'true'
+        return heat.stacks.update(stack.id, **stack_args)
+
+    def set_tls_parameters(self, parameters, env,
+                           local_ca_path=constants.LOCAL_CACERT_PATH):
+        cacert_string = self._get_local_cacert(local_ca_path)
+        if cacert_string:
+            parameters['CAMap'] = self._get_updated_camap_entry(
+                'undercloud-ca', cacert_string, self._get_camap(env))
+
+    def _get_local_cacert(self, local_ca_path):
+        # Since the undercloud has TLS by default, we'll add the undercloud's
+        # CA to be trusted by the overcloud.
         try:
-            return heat.stacks.update(stack.id, **stack_args)
-        except heat_exc.HTTPException as err:
-            err_msg = "Error during stack update: %s" % (err,)
-            LOG.exception(err_msg)
-            return actions.Result(error=err_msg)
+            with open(local_ca_path, 'rb') as ca_file:
+                return ca_file.read()
+        except IOError:
+            # If the file wasn't found it means that the undercloud's TLS
+            # was explicitly disabled or another CA is being used. So we'll
+            # let the user handle this.
+            return None
+        except Exception:
+            raise
+
+    def _get_camap(self, env):
+        return env['parameter_defaults'].get('CAMap', {})
+
+    def _get_updated_camap_entry(self, entry_name, cacert, orig_camap):
+        ca_map_entry = {
+            entry_name: {
+                'content': cacert
+            }
+        }
+        orig_camap.update(ca_map_entry)
+        return orig_camap
 
 
 class OvercloudRcAction(base.TripleOAction):
@@ -265,56 +287,4 @@ class OvercloudRcAction(base.TripleOAction):
                      "environment.")
             return actions.Result(error=error)
 
-        region_name = parameter_defaults.get('KeystoneRegion')
-        return overcloudrc.create_overcloudrc(stack, self.no_proxy, admin_pass,
-                                              region_name)
-
-
-class DeploymentFailuresAction(base.TripleOAction):
-    """Return all of the failures (if any) from deploying the plan
-
-    :param plan: name of the Swift container / plan name
-    """
-
-    def __init__(self,
-                 plan=constants.DEFAULT_CONTAINER_NAME,
-                 deployment_status_file=constants.DEPLOYMENT_STATUS_FILE,
-                 work_dir=constants.MISTRAL_WORK_DIR,
-                 ansible_errors_file=constants.ANSIBLE_ERRORS_FILE):
-        super(DeploymentFailuresAction, self).__init__()
-        self.plan = plan
-        self.messages_container = "%s-messages" % self.plan
-        self.deployment_status_file = deployment_status_file
-        self.work_dir = work_dir
-        self.ansible_errors_file = ansible_errors_file
-
-    def _format_return(self, message, failures={}):
-        return dict(message=message,
-                    failures=failures)
-
-    def run(self, context):
-        swift = self.get_object_client(context)
-
-        try:
-            deployment_status_obj = swift.get_object(
-                self.messages_container, self.deployment_status_file)[1]
-        except swiftexceptions.ClientException:
-            return self._format_return(
-                'Swift container %s not found' % self.messages_container)
-
-        try:
-            deployment_status = yaml.safe_load(deployment_status_obj)
-            execution_id = \
-                deployment_status['workflow_status']['payload']['execution_id']
-        except KeyError:
-            return self._format_return(
-                'Execution not found in %s' % self.deployment_status_file)
-
-        try:
-            failures_file = os.path.join(self.work_dir, execution_id,
-                                         self.ansible_errors_file)
-            failures = json.loads(open(failures_file).read())
-            return self._format_return('', failures)
-        except IOError:
-            return self._format_return(
-                'Ansible errors file not found at %s' % failures_file)
+        return overcloudrc.create_overcloudrc(stack, self.no_proxy, admin_pass)
