@@ -27,7 +27,7 @@ from tripleo_common.actions import templates
 from tripleo_common import constants
 from tripleo_common import exception
 from tripleo_common.utils import nodes
-from tripleo_common.utils import parameters
+from tripleo_common.utils import parameters as parameter_utils
 from tripleo_common.utils import passwords as password_utils
 from tripleo_common.utils import plan as plan_utils
 
@@ -127,13 +127,11 @@ class UpdateParametersAction(templates.ProcessTemplatesAction):
 
     def __init__(self, parameters,
                  container=constants.DEFAULT_CONTAINER_NAME,
-                 key=constants.DEFAULT_PLAN_ENV_KEY,
-                 validate=True):
+                 key=constants.DEFAULT_PLAN_ENV_KEY):
         super(UpdateParametersAction, self).__init__()
         self.container = container
         self.parameters = parameters
         self.key = key
-        self.validate = validate
 
     def run(self, context):
         swift = self.get_object_client(context)
@@ -166,9 +164,8 @@ class UpdateParametersAction(templates.ProcessTemplatesAction):
         if isinstance(processed_data, actions.Result):
             return processed_data
 
+        processed_data['show_nested'] = True
         env = plan_utils.get_env(swift, self.container)
-        if not self.validate:
-            return env
 
         params = env.get('parameter_defaults')
         fields = {
@@ -226,7 +223,7 @@ class UpdateRoleParametersAction(UpdateParametersAction):
     def run(self, context):
         baremetal_client = self.get_baremetal_client(context)
         compute_client = self.get_compute_client(context)
-        self.parameters = parameters.set_count_and_flavor_params(
+        self.parameters = parameter_utils.set_count_and_flavor_params(
             self.role, baremetal_client, compute_client)
         return super(UpdateRoleParametersAction, self).run(context)
 
@@ -280,6 +277,13 @@ class GeneratePasswordsAction(base.TripleOAction):
         if 'passwords' not in env:
             env['passwords'] = {}
 
+        # NOTE(ansmith): if rabbit password previously generated and
+        # stored, facilitate upgrade and use for oslo messaging in plan env
+        if 'RabbitPassword' in env['passwords']:
+            for i in ('RpcPassword', 'NotifyPassword'):
+                if i not in env['passwords']:
+                    env['passwords'][i] = env['passwords']['RabbitPassword']
+
         # ensure all generated passwords are present in plan env,
         # but respect any values previously generated and stored
         for name, password in passwords.items():
@@ -368,17 +372,17 @@ class GenerateFencingParametersAction(base.TripleOAction):
             if "mac" in node:
                 # Not all Ironic drivers present a MAC address, so we only
                 # capture it if it's present
-                mac_addr = node["mac"][0].lower()
+                mac_addr = node["mac"][0]
                 node_data["host_mac"] = mac_addr
 
                 # If the MAC isn't in the hostmap, this node hasn't been
                 # provisioned, so no fencing parameters are necessary
-                if hostmap and mac_addr not in hostmap:
+                if mac_addr not in hostmap:
                     continue
 
             # Build up fencing parameters based on which Ironic driver this
             # node is using
-            if hostmap and node["pm_type"] == "pxe_ssh":
+            if node["pm_type"] == "pxe_ssh":
                 # Ironic fencing driver
                 node_data["agent"] = "fence_ironic"
                 params["auth_url"] = self.os_auth["auth_url"]
@@ -390,20 +394,6 @@ class GenerateFencingParametersAction(base.TripleOAction):
                      "bm_name": hostmap[mac_addr]["baremetal_name"]})
                 if self.delay:
                     params["delay"] = self.delay
-            elif (node['pm_type'] in {'staging-ovirt'}):
-                # fence_rhevm
-                node_data["agent"] = "fence_rhevm"
-                params["ipaddr"] = node["pm_addr"]
-                params["passwd"] = node["pm_password"]
-                params["login"] = node["pm_user"]
-                params["port"] = node["pm_vm_name"]
-                params["ssl"] = 1
-                params["ssl_insecure"] = 1
-                if hostmap:
-                    params["pcmk_host_list"] = \
-                        hostmap[mac_addr]["compute_name"]
-                if self.delay:
-                    params["delay"] = self.delay
             elif (node['pm_type'] == 'ipmi' or node["pm_type"].split('_')[1] in
                   ("ipmitool", "ilo", "drac")):
                 # IPMI fencing driver
@@ -411,9 +401,7 @@ class GenerateFencingParametersAction(base.TripleOAction):
                 params["ipaddr"] = node["pm_addr"]
                 params["passwd"] = node["pm_password"]
                 params["login"] = node["pm_user"]
-                if hostmap:
-                    params["pcmk_host_list"] = \
-                        hostmap[mac_addr]["compute_name"]
+                params["pcmk_host_list"] = hostmap[mac_addr]["compute_name"]
                 if "pm_port" in node:
                     params["ipport"] = node["pm_port"]
                 if self.ipmi_lanplus:
@@ -527,8 +515,8 @@ class GetProfileOfFlavorAction(base.TripleOAction):
     def run(self, context):
         compute_client = self.get_compute_client(context)
         try:
-            return parameters.get_profile_of_flavor(self.flavor_name,
-                                                    compute_client)
+            return parameter_utils.get_profile_of_flavor(self.flavor_name,
+                                                         compute_client)
         except exception.DeriveParamsError as err:
             LOG.error('Derive Params Error: %s', err)
             return actions.Result(error=str(err))
