@@ -15,9 +15,9 @@
 
 
 import abc
+from concurrent import futures
 import json
 import logging
-import multiprocessing
 import netifaces
 import os
 import requests
@@ -33,7 +33,6 @@ except ImportError:
     from docker import Client
 from oslo_concurrency import processutils
 from tripleo_common.image.base import BaseImageManager
-from tripleo_common.image.exception import ImageNotFoundException
 from tripleo_common.image.exception import ImageUploaderException
 
 
@@ -46,6 +45,15 @@ SECURE_REGISTRIES = (
 )
 
 
+def get_undercloud_registry():
+    addr = 'localhost'
+    if 'br-ctlplane' in netifaces.interfaces():
+        addrs = netifaces.ifaddresses('br-ctlplane')
+        if netifaces.AF_INET in addrs and addrs[netifaces.AF_INET]:
+            addr = addrs[netifaces.AF_INET][0].get('addr', 'localhost')
+    return '%s:%s' % (addr, '8787')
+
+
 class ImageUploadManager(BaseImageManager):
     """Manage the uploading of image files
 
@@ -77,14 +85,14 @@ class ImageUploadManager(BaseImageManager):
         uploads = self.load_config_files(self.UPLOADS) or []
         container_images = self.load_config_files(self.CONTAINER_IMAGES) or []
         upload_images = uploads + container_images
-        default_push_destination = self.get_ctrl_plane_ip() + ':8787'
 
         for item in upload_images:
             image_name = item.get('imagename')
             uploader = item.get('uploader', 'docker')
             pull_source = item.get('pull_source')
-            push_destination = item.get('push_destination',
-                                        default_push_destination)
+            push_destination = item.get('push_destination')
+            if not push_destination:
+                push_destination = get_undercloud_registry()
 
             # This updates the parsed upload_images dict with real values
             item['push_destination'] = push_destination
@@ -97,14 +105,6 @@ class ImageUploadManager(BaseImageManager):
 
         return upload_images  # simply to make test validation easier
 
-    def get_ctrl_plane_ip(self):
-        addr = 'localhost'
-        if 'br-ctlplane' in netifaces.interfaces():
-            addrs = netifaces.ifaddresses('br-ctlplane')
-            if netifaces.AF_INET in addrs and addrs[netifaces.AF_INET]:
-                addr = addrs[netifaces.AF_INET][0].get('addr', 'localhost')
-        return addr
-
 
 @six.add_metaclass(abc.ABCMeta)
 class ImageUploader(object):
@@ -147,7 +147,7 @@ class DockerImageUploader(ImageUploader):
 
     def __init__(self):
         self.upload_tasks = []
-        self.secure_registries = set()
+        self.secure_registries = set(SECURE_REGISTRIES)
         self.insecure_registries = set()
 
     @staticmethod
@@ -242,12 +242,6 @@ class DockerImageUploader(ImageUploader):
         return i.get('Digest')
 
     @staticmethod
-    @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
-        reraise=True,
-        retry=tenacity.retry_if_exception_type(ImageUploaderException),
-        wait=tenacity.wait_random_exponential(multiplier=1, max=10),
-        stop=tenacity.stop_after_attempt(5)
-    )
     def _inspect(image, insecure=False):
 
         cmd = ['skopeo', 'inspect']
@@ -263,14 +257,6 @@ class DockerImageUploader(ImageUploader):
 
         out, err = process.communicate()
         if process.returncode != 0:
-            not_found_msgs = (
-                'manifest unknown',
-                # returned by docker.io
-                'requested access to the resource is denied'
-            )
-            if any(n in err for n in not_found_msgs):
-                raise ImageNotFoundException('Not found image: %s\n%s' %
-                                             (image, err))
             raise ImageUploaderException('Error inspecting image: %s\n%s' %
                                          (image, err))
         return json.loads(out)
@@ -337,7 +323,7 @@ class DockerImageUploader(ImageUploader):
         for image in images:
             discover_args.append((image, tag_from_label,
                                   self.insecure_registries))
-        p = multiprocessing.Pool(16)
+        p = futures.ThreadPoolExecutor(max_workers=16)
 
         versioned_images = {}
         for image, versioned_image in p.map(discover_tag_from_inspect,
@@ -390,7 +376,7 @@ class DockerImageUploader(ImageUploader):
 
         # workers will be half the CPU count, to a minimum of 2
         workers = max(2, processutils.get_worker_count() // 2)
-        p = multiprocessing.Pool(workers)
+        p = futures.ThreadPoolExecutor(max_workers=workers)
 
         for result in p.map(docker_upload, self.upload_tasks):
             local_images.extend(result)
