@@ -13,6 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import mock
+import tempfile
 import yaml
 
 from heatclient import exc as heat_exc
@@ -204,6 +205,9 @@ class OrchestrationDeployActionTest(base.TestCase):
 
 class DeployStackActionTest(base.TestCase):
 
+    def setUp(self,):
+        super(DeployStackActionTest, self).setUp()
+
     @mock.patch('tripleo_common.actions.deployment.time')
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
@@ -358,99 +362,58 @@ class DeployStackActionTest(base.TestCase):
             "overcloud-swift-rings", "swift-rings.tar.gz",
             "overcloud-swift-rings/swift-rings.tar.gz-%d" % 1473366264)
 
-    @mock.patch('tripleo_common.actions.deployment.time')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    @mock.patch(
-        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
-    def test_run_create_failed(
-        self, get_orchestration_client_mock, mock_get_object_client,
-        mock_get_template_contents,
-        mock_process_multiple_environments_and_files, mock_time):
+    def test_set_tls_parameters_no_ca_found(self):
+        action = deployment.DeployStackAction(1, 'overcloud',
+                                              skip_deploy_identifier=True)
+        my_params = {}
+        my_env = {'parameter_defaults': {}}
+        action.set_tls_parameters(parameters=my_params, env=my_env,
+                                  local_ca_path='/tmp/my-unexistent-file.txt')
+        self.assertEqual(my_params, {})
 
-        mock_ctx = mock.MagicMock()
-        # setup swift
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'name': 'overcloud',
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-            'parameter_defaults': {'random_existing_data': 'a_value'},
-        }, default_flow_style=False)
-        swift.get_object.side_effect = (
-            ({}, mock_env),
-            ({}, mock_env),
-            swiftexceptions.ClientException('atest2')
-        )
-        mock_get_object_client.return_value = swift
+    def test_set_tls_parameters_ca_found_no_camap_provided(self):
+        action = deployment.DeployStackAction(1, 'overcloud',
+                                              skip_deploy_identifier=True)
+        my_params = {}
+        my_env = {'parameter_defaults': {}}
+        with tempfile.NamedTemporaryFile() as ca_file:
+            # Write test data
+            ca_file.write(b'FAKE CA CERT')
+            ca_file.flush()
 
-        heat = mock.MagicMock()
-        heat.stacks.get.return_value = None
-        heat.stacks.create.side_effect = heat_exc.HTTPException("Oops")
-        get_orchestration_client_mock.return_value = heat
+            # Test
+            action.set_tls_parameters(parameters=my_params, env=my_env,
+                                      local_ca_path=ca_file.name)
+            self.assertIn('CAMap', my_params)
+            self.assertIn('undercloud-ca', my_params['CAMap'])
+            self.assertIn('content', my_params['CAMap']['undercloud-ca'])
+            self.assertEqual(b'FAKE CA CERT',
+                             my_params['CAMap']['undercloud-ca']['content'])
 
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30'
-        })
-        mock_process_multiple_environments_and_files.return_value = ({}, {})
+    def test_set_tls_parameters_ca_found_camap_provided(self):
+        action = deployment.DeployStackAction(1, 'overcloud',
+                                              skip_deploy_identifier=True)
+        my_params = {}
+        my_env = {
+            'parameter_defaults': {
+                'CAMap': {'overcloud-ca': {'content': b'ANOTER FAKE CERT'}}}}
+        with tempfile.NamedTemporaryFile() as ca_file:
+            # Write test data
+            ca_file.write(b'FAKE CA CERT')
+            ca_file.flush()
 
-        # freeze time at datetime.datetime(2016, 9, 8, 16, 24, 24)
-        mock_time.time.return_value = 1473366264
-
-        action = deployment.DeployStackAction(1, 'overcloud')
-        expected = actions.Result(
-            error="Error during stack creation: ERROR: Oops\n")
-        self.assertEqual(expected, action.run(mock_ctx))
-
-    @mock.patch('tripleo_common.actions.deployment.time')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    @mock.patch(
-        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
-    def test_run_update_failed(
-        self, get_orchestration_client_mock, mock_get_object_client,
-        mock_get_template_contents,
-        mock_process_multiple_environments_and_files, mock_time):
-
-        mock_ctx = mock.MagicMock()
-        # setup swift
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'name': 'overcloud',
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-            'parameter_defaults': {'random_existing_data': 'a_value'},
-        }, default_flow_style=False)
-        swift.get_object.side_effect = (
-            ({}, mock_env),
-            ({}, mock_env),
-            swiftexceptions.ClientException('atest2')
-        )
-        mock_get_object_client.return_value = swift
-
-        heat = mock.MagicMock()
-        heat.stacks.get.return_value = mock.Mock()
-        heat.stacks.update.side_effect = heat_exc.HTTPException("Oops")
-        get_orchestration_client_mock.return_value = heat
-
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30'
-        })
-        mock_process_multiple_environments_and_files.return_value = ({}, {})
-
-        # freeze time at datetime.datetime(2016, 9, 8, 16, 24, 24)
-        mock_time.time.return_value = 1473366264
-
-        action = deployment.DeployStackAction(1, 'overcloud')
-        expected = actions.Result(
-            error="Error during stack update: ERROR: Oops\n")
-        self.assertEqual(expected, action.run(mock_ctx))
+            # Test
+            action.set_tls_parameters(parameters=my_params, env=my_env,
+                                      local_ca_path=ca_file.name)
+            self.assertIn('CAMap', my_params)
+            self.assertIn('undercloud-ca', my_params['CAMap'])
+            self.assertIn('content', my_params['CAMap']['undercloud-ca'])
+            self.assertEqual(b'FAKE CA CERT',
+                             my_params['CAMap']['undercloud-ca']['content'])
+            self.assertIn('overcloud-ca', my_params['CAMap'])
+            self.assertIn('content', my_params['CAMap']['overcloud-ca'])
+            self.assertEqual(b'ANOTER FAKE CERT',
+                             my_params['CAMap']['overcloud-ca']['content'])
 
 
 class OvercloudRcActionTestCase(base.TestCase):
